## 0.0.27

This new version includes several important updates to improve the functionality and security of the Llamabot application.

### New Features

- All websocket origins are now allowed, enhancing the connectivity and compatibility of the application (a685f0) (Eric Ma)

### Bug Fixes

- Fixed the issue with the Querybot index retriever by updating it with the refactored Llamaindex code. This should improve the accuracy and efficiency of the index retriever (12a87b) (Eric Ma)

### Deprecations

- The opening of the app has been disabled. This is a temporary measure for security reasons and will be addressed in future updates (e6e1a4) (Eric Ma)
